jhbuild r2760 - in trunk: . jhbuild/versioncontrol



Author: asabil
Date: Thu Mar 12 09:29:29 2009
New Revision: 2760
URL: http://svn.gnome.org/viewvc/jhbuild?rev=2760&view=rev

Log:
2009-03-12  Ali Sabil  <ali sabil gmail com>

	* jhbuild/versioncontrol/bzr.py: add support for bzr://, bzr+ssh:// and
	lp: URIs




Modified:
   trunk/ChangeLog
   trunk/jhbuild/versioncontrol/bzr.py

Modified: trunk/jhbuild/versioncontrol/bzr.py
==============================================================================
--- trunk/jhbuild/versioncontrol/bzr.py	(original)
+++ trunk/jhbuild/versioncontrol/bzr.py	Thu Mar 12 09:29:29 2009
@@ -29,12 +29,22 @@
 from jhbuild.versioncontrol import Repository, Branch, register_repo_type
 from jhbuild.commands.sanitycheck import inpath
 
 # Make sure that the urlparse module considers sftp://
 # scheme to be netloc aware and set to allow relative URIs.
+if 'bzr' not in urlparse.uses_netloc:
+    urlparse.uses_netloc.append('bzr')
+if 'bzr' not in urlparse.uses_relative:
+    urlparse.uses_relative.append('bzr')
+if 'bzr+ssh' not in urlparse.uses_netloc:
+    urlparse.uses_netloc.append('bzr+ssh')
+if 'bzr+ssh' not in urlparse.uses_relative:
+    urlparse.uses_relative.append('bzr+ssh')
 if 'sftp' not in urlparse.uses_netloc:
     urlparse.uses_netloc.append('sftp')
 if 'sftp' not in urlparse.uses_relative:
     urlparse.uses_relative.append('sftp')
+if 'lp' not in urlparse.uses_relative:
+    urlparse.uses_relative.append('lp')
 
 
 class BzrRepository(Repository):
@@ -29,12 +29,22 @@
 from jhbuild.commands.sanitycheck import inpath
 
-# Make sure that the urlparse module considers sftp://
+# Make sure that the urlparse module considers bzr://, bzr+ssh://, sftp:// and lp:
 # scheme to be netloc aware and set to allow relative URIs.



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]